
# a script to run the nMDS ordination and generate plots


# nMDS beetle samples, fig 2  -----

# subset metadata to beetle samples with sequencing data, minimum 10 reads
# and columns for 'sex' (female/male) and 'region' (body vs gut)
# add a column that identifies body and gut sample from same individuals called 'beetle_individual'
meta_seq_beetle <- meta_seq %>% filter(seq_plate == "BodyGut") %>%
    separate(.,
        substrate,
        c("sex", "region"),
        sep = ", ",
        remove = FALSE,
        convert = FALSE
    ) %>%
    mutate(sex = as.factor(sex),
           region = as.factor(region)) %>%
    droplevels() %>%
    mutate(beetle_individual = sample_id) %>%
    mutate(beetle_individual = gsub("TPF[BG]", "TPF", beetle_individual)) %>%
    mutate(beetle_individual = gsub("TPM[BG]", "TPM", beetle_individual))
row.names(meta_seq_beetle) <- meta_seq_beetle$sample_id

# trim the otu table down to beetle samples only
otutab_beetle <-
    otutab_min10[row.names(otutab_min10) %in% row.names(meta_seq_beetle), ]
otutab_beetle <- otutab_beetle[, colSums(otutab_beetle) > 0]

# assign 'sample_id' to row names
row.names(meta_seq_beetle) <- meta_seq_beetle$sample_id

# make sure metadata and otu table have rows (samples) in the same order
meta_seq_beetle <- meta_seq_beetle[row.names(otutab_beetle), ]


# run NMDS using relative abundance and Bray-Curtis Dissimilarity Index, and 2 dimensions
otutab_beetle_ra <- decostand(otutab_beetle, method = "total")
set.seed(9032)
nmds_beetle <-
    metaMDS(otutab_beetle_ra,
            distance = "bray",
            k = 2,
            trymax = 200)





# nMDS phloem samples, fig 3 -----


# subset metadata to include only phloem samples with sequencing data, minimum 10 reads
meta_seq_phloem <-
    meta_seq %>% filter(seq_plate == "Wood") %>% droplevels()
row.names(meta_seq_phloem) <- meta_seq_phloem$sample_id

# subset otu table
otutab_phloem <-
    otutab_min10[row.names(otutab_min10) %in% row.names(meta_seq_phloem), ]
otutab_phloem <- otutab_phloem[, colSums(otutab_phloem) > 0]

# assign 'sample_id' to row names
row.names(meta_seq_beetle) <- meta_seq_beetle$sample_id

# make sure metadata and otu table have rows (samples) in the same order
meta_seq_phloem <- meta_seq_phloem[row.names(otutab_phloem), ]


# run NMDS using relative abundance, Bray-Curtis Dissimilarity, and 2 dimensions
otutab_phloem_ra <- decostand(otutab_phloem, method = "total")
set.seed(8643)
nmds_phloem <-
    metaMDS(otutab_phloem_ra,
            distance = "bray",
            k = 2,
            trymax = 200)






# nMDS all samples, fig 4 -----

# assign 'sample_id' to row names of metadata table
row.names(meta_seq) <- meta_seq$sample_id

# make sure metadata and otu table have rows (samples) in the same order
meta_seq_min10 <- meta_seq[row.names(otutab_min10), ] %>% droplevels()

# run NMDS using relative abundance, Bray-Curtis Dissimilarity, and 2 dimensions
otutab_min10_ra <- decostand(otutab_min10, method = "total")
set.seed(3894)
nmds_min10 <-
    metaMDS(otutab_min10_ra,
            distance = "bray",
            k = 2,
            trymax = 200)




# plots -----


# fig 2 - nmds bark beetle samples
fig2_beetle_nmds <- as.data.frame(scores(nmds_beetle)) %>%
    merge(., meta_seq_beetle, by = 0) %>%
    ggplot(aes(
        x = NMDS1,
        y = NMDS2,
        col = substrate,
        pch = site
    )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_shape_manual("Site and fire history: ",
                       values = shape_by_firehist_and_site,
                       labels = label_by_site) +
        scale_color_manual(" ", values = color_by_substrate)


# sample plot as fig 2 highlighting body vs gut
fig2_beetle_nmds_region <- as.data.frame(scores(nmds_beetle)) %>%
    merge(., meta_seq_beetle, by = 0) %>%
    ggplot(aes(
        x = NMDS1,
        y = NMDS2,
        col = region
    )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_color_manual(" ", values = c(`body` = "#00204D", `gut` = "#E7D159"))


# sample plot as fig 2 highlighting sex
fig2_beetle_nmds_sex <- as.data.frame(scores(nmds_beetle)) %>%
    merge(., meta_seq_beetle, by = 0) %>%
    ggplot(aes(
        x = NMDS1,
        y = NMDS2,
        col = sex
        )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_color_manual(" ", values = c(`female` = "#35608D", `male` = "#BBDF27"))





# supp fig 1 plot from fig 2 with lines added connecting beetle samples from same individual
supp_fig1_beetle_nmds_with_lines <- as.data.frame(scores(nmds_beetle)) %>%
    merge(., meta_seq_beetle, by = 0) %>%
    ggplot(aes(
        x = NMDS1,
        y = NMDS2,
        col = substrate,
        pch = site
    )) +
    geom_point() +
    geom_line(
        aes(group = beetle_individual),
        color = 'dimgrey',
        alpha = 0.5,
        size = 1
    ) +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_shape_manual("Site and fire history: ",
                       values = shape_by_firehist_and_site,
                       labels = label_by_site) +
        scale_color_manual(" ", values = color_by_substrate)



# fig 3 - nmds phloem samples
fig3_phloem_nmds <- as.data.frame(scores(nmds_phloem)) %>%
    merge(., meta_seq_phloem, by = 0) %>%
    ggplot(aes(
        x = NMDS1,
        y = NMDS2,
        pch = site,
        col = substrate
    )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_color_manual(" ", values = color_by_substrate) +
    scale_shape_manual("Site and fire history: ",
                       values = shape_by_firehist_and_site,
                       labels = label_by_site)





# nmds all samples

# get a dataframe with sample coordinates and metadata
nmdsmin10_df <- as.data.frame(scores(nmds_min10)) %>%
    merge(., meta_seq_min10, by = 0)

# fig 4 - nmds all samples
fig4_all_samples_nmds <-
    ggplot(data = nmdsmin10_df,
           aes(
               x = NMDS1,
               y = NMDS2,
               pch = site,
               col = substrate_collapsed_4
           )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "left",
          panel.grid = element_blank()) +
    scale_color_manual("Sample origin: ",
                       values = color_by_substrate) +
    scale_shape_manual("Site and fire history: ",
                       labels = label_by_site,
                       values = shape_by_firehist_and_site)


# same plot as fig 4, just highlighting burnt vs unburnt samples
fig4_all_samples_nmds_fire_hist <-
    ggplot(data = nmdsmin10_df,
           aes(
               x = NMDS1,
               y = NMDS2,
               pch = site,
               col = fire_hist
           )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_color_manual(name = "Fire history: ",
                       values = c(`burnt` = "#140B34", `unburnt` = "#F6D645")) +
    scale_shape_manual(name = "Site: ",
                       labels = label_by_site,
                       values = shape_by_firehist_and_site)


# same plot as fig 4, just highlighting beetle vs phloem samples
fig4_all_samples_nmds_seq_plate <-
    ggplot(data = nmdsmin10_df,
           aes(
               x = NMDS1,
               y = NMDS2,
               pch = site,
               col = seq_plate
           )) +
    geom_point() +
    coord_fixed(ratio = 1) +
    labs(x = "nMDS 1", y = "nMDS 2") +
    theme_bw() +
    theme(legend.position = "right",
          panel.grid = element_blank()) +
    scale_color_manual(
        name = "Sample origin: ",
        labels = c(`BodyGut` = "beetle",
                   `Wood` = "phloem"),
        values = c(`BodyGut` = "#FCA90E", `Wood` = "#84206B")
    ) +
    scale_shape_manual(name = "Site: ",
                       labels = label_by_site,
                       values = shape_by_firehist_and_site)

