#!/usr/bin/env python3.7
import sys
import argparse

# Replaces empty taxonostring fields in the UNITE reference dataset
# with 'Incertae_sedis'.  For example, this script turns
# this: "...c:Ulvophyceae,o:,f:,g:Desmochloris,s:Desmochloris_halophila..."
# into this: "...c:Ulvophyceae,o:Ulvophyceae_order_Incertae_sedis, \
#  f:Ulvophyceae_fam_Incertae_sedis,g:Desmochloris,s:Desmochloris_halophila..."

# usage:    add_Incertae_sedis.py -i <input file> -o <output file>

# Input option '-i' is meant to allow for variation in path to file, but
# input file should be 'utax_reference_dataset_all_02.02.2019.fasta'
# (UTAX/USEARCH version 8, all Eukaryotes, DOI: 10.15156/BIO/786346)
# available at: https://dx.doi.org/10.15156/BIO/786346


##### GET DATA AND OUTPUT FILE #####

# get -i and -o options
parser = argparse.ArgumentParser()

parser.add_argument("-i", help="input file should be \
'utax_reference_dataset_all_02.02.2019.fasta'", required=True)
parser.add_argument("-o", help="name of output file", required=True)
args = parser.parse_args()

# get input and output files
input_f = args.i
output_f = args.o

##### FIX BLANK HEADINGS #####

print("- Detecting blank fields in taxonomy strings in file: %s"%(input_f))
print("- Changing all instances of '[c|o|f]>:,' to: \n    '[c|o|f]: \
<name_of_last_known_rank>_<cls|ord|fam>_Incertae_sedis,'")

# loop through each line, if it is a tax line, check for blank class,
# order, or family, and add Incertae sedis when needed.
# if it is a sequence line, print the line as-is.
with open(input_f, 'r') as fasta_lines:
    new_fasta_lines=[]
    for fas_line in fasta_lines:
        if fas_line.startswith('>'):
            old_tax = fas_line.split(',')
            ins = ()
            for part in old_tax:
                part.rstrip('\n')
                if part.startswith('>'):
                    new_tax = [part, ',']
                elif len(part) > 2:
                    new_tax.extend((part, ','))
                    ins = part[2:]
                elif part == 'c:':
                    new_tax.extend(('c:', ins, '_cls_Incertae_sedis,'))
                elif part == 'o:':
                    new_tax.extend(('o:', ins, '_ord_Incertae_sedis,'))
                elif part == 'f:':
                    new_tax.extend(('f:', ins, '_fam_Incertae_sedis,'))
            new_tax = ''.join(new_tax)
            new_fasta_lines.append(new_tax[:-1])
        elif not fas_line.startswith('>'):
            new_fasta_lines.extend((fas_line.rstrip('\n'), '\n'))

# open the new fasta file for printing
with open(output_f, 'w') as new_fasta:
    new_fasta.write(''.join(new_fasta_lines))
print("Done! New file: %s"%(output_f))
sys.exit(0)
