## ------------------------------------------------------
##
## Author: Kerri Kluting
##
## Email: klutingkl@gmail.com
##
## ------------------------------------------------------
##
## Notes: This script will process the initial OTU table by removing:
##   1. 'false' samples (non-existent tag/plate combos)
##   2. singletons/ OTUs not existing in these samples
##
##   initial OTU table has not yet been filtered based on ITSx results
##   (includes non-fungal OTUs, for example)
##
## ------------------------------------------------------

##### General settings ----

options(scipen = 999, digits = 4)  # turn off scientific notation
grDevices::pdf.options(useDingbats = FALSE)  # don't use dingbats in .pdf files


##### Package load ----

library("dplyr")
# other require packages:
# readxl
# tidyr

## ------------------------------------------------------


##### File paths ----

# script name
SCRIPT_NAME <- "tp_process_initial_otu_table.R"

# path to input files

# tidied metadata file
IN_META <-
    list.files(path = "./data",
               pattern = "tp_metadata_",
               full.names = TRUE)

# otu table (output file from SCATA)
SCATA_OTUTAB <- "./data/pre_analysis/orig_and_ref_data/scata3997/all_tag_by_cluster_counts.txt"




# paths and names of output files:

# output file names
# initial OTU table
OUT_INITIAL_OTUTAB <- "./data/tp_initial_otu_table.txt"
# list of OTUs in initial OTU table
OUT_INITIAL_OTUS_LIST <- "./data/pre_analysis/tp_initial_otus_list.txt"

# RSession information (package versions, etc.)
OUT_RS <-
    paste0(
        "./data/pre_analysis/Rsess_info/",
        tools::file_path_sans_ext(SCRIPT_NAME),
        "_RSess_",
        strftime(Sys.time(), '%Y%m%d'),
        ".txt"
    )

if (!dir.exists("./data/pre_analysis/Rsess_info/")) {
    dir.create("./data/pre_analysis/Rsess_info/")
}

## ------------------------------------------------------


##### Load data ----

# read in SCATA output OTU table
raw_scata_otutab <-
    read.table(
        SCATA_OTUTAB,
        row.names = 1,
        header = TRUE,
        sep = ";",
        check.names = FALSE
    )

# the first column in the otu table is called 'Tag', but was loaded as row names
# create a new variable called 'sample_seq_id' and copy the rownames to it
# and then reformat to match format in otu table from SCATA
otutab <-
    raw_scata_otutab %>%
    mutate(sample_seq_id = row.names(raw_scata_otutab)) %>%
    mutate(sample_seq_id = gsub("Pool 3 TP ", "", sample_seq_id)) %>%
    mutate(sample_seq_id = gsub("/", "", sample_seq_id)) %>%
    mutate(sample_seq_id = gsub(" ", ".", sample_seq_id))

# then, assign these newly reformated 'sample_id' to rownames
row.names(otutab) <- otutab$sample_seq_id

# read in metadata table to get correct list of samples that have sequence data
samples_w_seq_id <-
    read.table(
        IN_META,
        header = TRUE,
        sep = "\t",
        na.strings = c("", "NA")
    ) %>%
    select(sample_id, seq_id) %>%
    filter(!is.na(seq_id))

# set rownames of samples_w_seq_id as seq_id, the tag combo id (ex. 'Wood.Tag3_Tag159')

row.names(samples_w_seq_id) <- samples_w_seq_id$seq_id

## ------------------------------------------------------

# filter the otu table to include only samples from this project
# new variable is called 'init_otutab' and in initial otu table that has
# only samples in this project and no singletons, but hasnt been filtered for example
# to remove non-fungal otus
init_otutab <- otutab[row.names(otutab) %in% samples_w_seq_id$seq_id, ]

# replace seq_id (primer tag combo) with 'sample_id'  as row names
init_otutab <- merge(init_otutab, samples_w_seq_id, by = 0)
row.names(init_otutab) <- init_otutab$sample_id
init_otutab$Row.names <- NULL

# remove the unwanted columns
init_otutab <- init_otutab %>% select(-sample_id, -sample_seq_id, -seq_id)

# filter out any singletons created by removing unwanted samples
init_otutab <- init_otutab[, colSums(init_otutab) > 1]

# now the otutab has sample ids (ex_ HBTPFB10) as rownames, and each otu as columns
# save to file
write.table(init_otutab, file = OUT_INITIAL_OTUTAB, col.names = NA,
            quote = FALSE, sep = "\t", eol = "\n", dec = ".", row.names = TRUE)

# get a list of otu ids left in 'init_otutab' for filtering the fasta file
# of otu representative sequences from SCATA using USEARCH
init_otus <- as.list(colnames(init_otutab))

# add "_repseq_0" to each otu id to match id names in SCATA fasta file
init_otus <- lapply(init_otus, paste0, "_repseq_0")

# save to file
cat(sapply(init_otus, toString), file = OUT_INITIAL_OTUS_LIST, sep = "\n")

# save a report of the R Session in case we need to know package or software versions later
sink(OUT_RS, append = FALSE)
cat("\n ## Script name:   ", SCRIPT_NAME, "\n")
cat(paste0("\n ## Date and time:  ", Sys.time()), "\n\n")
print(devtools::session_info())
cat("\n\n\n")
sink()














