## ------------------------------------------------------
##
## Author: Kerri Kluting
##
## Email: klutingkl@gmail.com
##
## ------------------------------------------------------
##
## Notes: This script takes as input the raw metadata file (TP BGW.xlsx)
##
## emailed to Kerri from Ylva on 3 Dec 2018
##
## and tidies it for downstream analysis
##
##
## ------------------------------------------------------

##### General settings ----

options(scipen = 999, digits = 4)  # turn off scientific notation
grDevices::pdf.options(useDingbats = FALSE)  # don't use dingbats in .pdf files


##### Package load ----

library("dplyr")
# other require packages:
# readxl
# tidyr

## ------------------------------------------------------


##### File paths ----

# script name
SCRIPT_NAME <- "tp_process_metadata.R"

# path to input file
IN_RAW_META <- "./data/pre_analysis/orig_and_ref_data/TP\ BGW.xlsx"


# paths and names of output files:

# tidied metadata file
OUT_META <-
    paste0("./data/tp_metadata_", strftime(Sys.time(), '%Y%m%d'), ".txt")

# RSession information (package versions, etc.)
OUT_RS <-
    paste0(
        "./data/pre_analysis/Rsess_info/",
        tools::file_path_sans_ext(SCRIPT_NAME),
        "_RSess_",
        strftime(Sys.time(), '%Y%m%d'),
        ".txt"
    )


if (!dir.exists("./data/pre_analysis/Rsess_info/")) {
    dir.create("./data/pre_analysis/Rsess_info/")
}


## ------------------------------------------------------


##### Load data ----

# what to extract from input file

# excel sheet and range of cells to read in
sheet_no <- "Blad1"
cell_nos <- "A8:J477"

# new column names
new_var_names <- c(
    "tag",
    "sample_id",
    "site",
    "fire_hist",
    "tree",
    "substrate_abbr_old",
    "sampling_time",
    "nitrogen",
    "carbon",
    "phosphorus"
)


# read in data
meta_raw <- readxl::read_excel(IN_RAW_META,
                               sheet = sheet_no,
                               range = cell_nos,
                               col_names = new_var_names)



##### Tidy data ----

meta_tidy <- meta_raw %>%

    mutate(
        # add 'substrate_abbr', adjusted from 'substrate_abbr_old'
        substrate_abbr = case_when(
            substrate_abbr_old == "BBFB" ~ "BB_FB",
            substrate_abbr_old == "BBFG" ~ "BB_FG",
            substrate_abbr_old == "BBMB" ~ "BB_MB",
            substrate_abbr_old == "BBMG" ~ "BB_MG",
            substrate_abbr_old == "WCONT" &
                sampling_time == "t0" ~ "PH_PRECOL",
            substrate_abbr_old == "WCONT" &
                sampling_time == "t1" ~ "PH_UNCOL_1ST",
            substrate_abbr_old == "WCONT" &
                sampling_time == "t2" ~ "PH_UNCOL_3RD",
            substrate_abbr_old == "WCOL" &
                sampling_time == "t1" ~ "PH_COL_1ST",
            substrate_abbr_old == "WCOL" &
                sampling_time == "t2" ~ "PH_COL_3RD"
        ),

        # make sure factor names are consistent
        site = case_when(site == "Oj" ~ "OJ",
                         TRUE ~ site),
        tree = case_when(
            tree == "SK2" ~ "S2",
            tree == "SK3" ~ "S3",
            tree == "SK5" ~ "S5",
            tree == "No Tree" ~ "no tree",
            TRUE ~ tree
        ),

        # recode 'fire_hist' for simplicity
        fire_hist = case_when(fire_hist == "Burn" ~ "burnt",
                              fire_hist == "No Burn" ~ "unburnt"),

        # add 'plate' (wood vs body/gut sequencing plate) for samples with sequence data
        seq_plate = case_when(
            !is.na(tag) & tree == "no tree" ~ "BodyGut",
            !is.na(tag) & tree != 'no tree' ~ "Wood"
        ),

        # make 'seq_id' to match SCATA output labels by combining 'plate' and 'tag'
        seq_id = if_else(!is.na(tag), paste0(seq_plate, ".", tag), NULL)

    ) %>%

    mutate(
        # add 'substrate', expanded labels from 'substrate_abbr'
        substrate = case_when(
            substrate_abbr == "BB_FB" ~ "female, body",
            substrate_abbr == "BB_FG" ~ "female, gut",
            substrate_abbr == "BB_MB" ~ "male, body",
            substrate_abbr == "BB_MG" ~ "male, gut",
            substrate_abbr == "PH_PRECOL" ~ "pre-colonization",
            substrate_abbr == "PH_UNCOL_1ST" ~ "1st instar, uncolonized",
            substrate_abbr == "PH_UNCOL_3RD" ~ "3rd instar, uncolonized",
            substrate_abbr == "PH_COL_1ST" ~ "1st instar, colonized",
            substrate_abbr == "PH_COL_3RD" ~ "3rd instar, colonized"
        )


    ) %>%

    mutate(
        # add 'bb_colonization', which is a collapsed version of substrate
        bb_colonization = case_when(
            grepl("BB_", substrate_abbr) ~ "beetle",
            substrate == "pre-colonization" ~ "pre-colonization",
            grepl("_UNCOL_", substrate_abbr) ~ "uncolonized",
            grepl("_COL_", substrate_abbr) ~ "colonized"
        )
    ) %>%

    mutate(# remove failed N/C measurements
        nitrogen = na_if(nitrogen, 0),
        carbon = na_if(carbon, 0)) %>%

    mutate(
        # sample with null value in either N or C must be null for both, since measurement is linked
        nitrogen = ifelse(is.na(carbon), carbon, nitrogen),
        carbon = ifelse(is.na(nitrogen), nitrogen, carbon)

    ) %>%

    mutate(
        # convert N and C to mg/kg instead of percent and round all values to 1 decimal place
        n_mg_kg = round(nitrogen * 10000, digits = 1),
        c_mg_kg = round(carbon * 10000, digits = 1),
        p_mg_kg = round(phosphorus, digits = 1) # phosphorus is already in mg/kg

    ) %>%

    mutate(
        # calculate molar mass for nitrogen, carbon, and phosphorus
        n_mol_kg = n_mg_kg / 14006.7,
        c_mol_kg = c_mg_kg / 12010.7,
        p_mol_kg = p_mg_kg / 30973.8

    ) %>%

    mutate(
        # calculate C:N, C:P, and N:P ratios
        cn_ratio = c_mol_kg / n_mol_kg,
        cp_ratio = c_mol_kg / p_mol_kg,
        np_ratio = n_mol_kg / p_mol_kg

    ) %>%

    # reorder the columns
    select(-nitrogen, -carbon, -phosphorus, -substrate_abbr_old)



##### Write output files ----


# write tidied data to a tab-delimited file
write.table(
    meta_tidy,
    file = OUT_META,
    na = "",
    quote = FALSE,
    row.names = FALSE,
    sep = "\t"
)


# print R session report to a text file
sink(OUT_RS, append = FALSE)
cat("\n ## Script name:   ", SCRIPT_NAME, "\n")
cat(paste0("\n ## Date and time:  ", Sys.time()), "\n\n")
print(devtools::session_info())
cat("\n\n\n")
sink()
